==> nui_firebase-0.0.13.tar.gz: lib/nui_firebase.dart <==
library nui_firebase;
import 'dart:developer';

import 'package:firebase_core/firebase_core.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_firebase/nui_firebase_models.dart';

export 'package:nui_firebase/nui_fireauth.dart';
export 'package:nui_firebase/nui_firebase_models.dart';
export 'package:nui_firebase/nui_firestore.dart';

class NUIFirebase{
  List<NUIFireBuilder> _builders = [];
  String _apiKey;
  String _appId;
  String _messagingSenderId;
  String _projectId;

  NUIFirebase withComponent(NUIFireBuilder builder){
    _builders.add(builder);
    return this;
  }

  NUIFirebase apiKey(String apiKey){
    _apiKey = apiKey;
    return this;
  }

  NUIFirebase appId(String appId){
    _appId = appId;
    return this;
  }

  NUIFirebase messagingSenderId(String messagingSenderId){
    _messagingSenderId = messagingSenderId;
    return this;
  }

  NUIFirebase projectId(String projectId){
    _projectId = projectId;
    return this;
  }

  Future<FireResult<FirebaseApp>> build() async{
    FireResult<FirebaseApp> result;
    try {
      final FirebaseApp fire = await Firebase.initializeApp(
        name: "NUIFirebase",
        options: FirebaseOptions(
            apiKey: _apiKey,
            appId: _appId,
            messagingSenderId: _messagingSenderId,
            projectId: _projectId
        )
      );
      result = FireResult(success: true, message: "Firebase initialized successfully", data: fire);
      for(NUIFireBuilder builder in _builders){
        builder.build(fire);
      }
      print("NUIFirebase: Initialization successful");
    } catch (e){
      print("NUIFirebase: Initialization failed with error : $e");
      result = FireResult(success: false, message: e.toString());
    }

    return result;
  }
}

class NUIFireComponent{
  String name(){}
}

class NUIFireBuilder<T extends NUIFireComponent>{
  T build(FirebaseApp app){}
}

==> nui_firebase-0.0.14.tar.gz: lib/nui_firebase.dart <==
library nui_firebase;
import 'dart:developer';

import 'package:firebase_core/firebase_core.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_firebase/nui_firebase_models.dart';

export 'package:nui_firebase/nui_fireauth.dart';
export 'package:nui_firebase/nui_firebase_models.dart';
export 'package:nui_firebase/nui_firestore.dart';

class NUIFirebase{
  List<NUIFireBuilder> _builders = [];
  String _apiKey;
  String _appId;
  String _messagingSenderId;
  String _projectId;

  NUIFirebase withComponent(NUIFireBuilder builder){
    _builders.add(builder);
    return this;
  }

  NUIFirebase apiKey(String apiKey){
    _apiKey = apiKey;
    return this;
  }

  NUIFirebase appId(String appId){
    _appId = appId;
    return this;
  }

  NUIFirebase messagingSenderId(String messagingSenderId){
    _messagingSenderId = messagingSenderId;
    return this;
  }

  NUIFirebase projectId(String projectId){
    _projectId = projectId;
    return this;
  }

  Future<FireResult<FirebaseApp>> build() async{
    FireResult<FirebaseApp> result;
    try {
      print("NUIFirebase: Initializing with apiKey:$_apiKey, appId:$_appId, projectId:$_projectId, messagingSenderId:$_messagingSenderId");
      final FirebaseApp fire = await Firebase.initializeApp(
        name: "NUIFirebase",
        options: FirebaseOptions(
            apiKey: _apiKey,
            appId: _appId,
            messagingSenderId: _messagingSenderId,
            projectId: _projectId
        )
      );
      print("NUIFirebase: Initialization successful for FirebaseApp");
      result = FireResult(success: true, message: "Firebase initialized successfully", data: fire);
      for(NUIFireBuilder builder in _builders){
        builder.build(fire);
      }

      print("NUIFirebase: Initialization successful for Fire Components");
    } catch (e){
      print("NUIFirebase: Initialization failed with error : $e");
      result = FireResult(success: false, message: e.toString());
    }

    return result;
  }
}

class NUIFireComponent{
  String name(){}
}

class NUIFireBuilder<T extends NUIFireComponent>{
  T build(FirebaseApp app){}
}
